@@ -72,6 +72,7 @@ __all__ = [
     "s_pluto_vl_forwarding_entry_s",
     "s_pluto_avb_params_s",
     "s_pluto_clock_sync_params_s",
+    "s_pluto_ptp_params_s",
     "s_pluto_custom_params_s",
     "s_pluto_switch_settings_s",
     "srad_pluto_settings",
@@ -83,6 +84,7 @@ __all__ = [
     "srad_jupiter_settings",
     "s_fire3_settings",
     "s_rad_moon_duo_settings",
+    "s_ether_badge_settings",
     "global_settings",
     "s_device_settings",
     "st_cm_iso157652_tx_message",
